@@ -1,8 +1,8 @@
 from typing import (
     Any,
     Callable,
-    Dict,
     List,
+    Mapping,
     Optional,
     Sequence,
     Tuple,
@@ -31,9 +31,9 @@ Handler = TypeVar("Handler")
 def request_schema(
     body: Optional[Body] = None,
     *,
-    query_params: Optional[Dict[str, Union[Type, QueryParam]]] = None,
-    headers: Optional[Dict[str, Union[str, Header]]] = None,
-    cookies: Optional[Dict[str, Union[str, Cookie]]] = None,
+    query_params: Optional[Mapping[str, Union[Type, QueryParam]]] = None,
+    headers: Optional[Mapping[str, Union[str, Header]]] = None,
+    cookies: Optional[Mapping[str, Union[str, Cookie]]] = None,
 ) -> Callable[[Handler], Handler]:
     ...
 
@@ -46,10 +46,10 @@ def request_schema(
     body_required: bool = False,
     body_description: Optional[str] = None,
     body_example: Optional[Any] = None,
-    body_examples: Optional[Dict[str, Union[Example, Any]]] = None,
-    query_params: Optional[Dict[str, Union[Type, QueryParam]]] = None,
-    headers: Optional[Dict[str, Union[str, Header]]] = None,
-    cookies: Optional[Dict[str, Union[str, Cookie]]] = None,
+    body_examples: Optional[Mapping[str, Union[Example, Any]]] = None,
+    query_params: Optional[Mapping[str, Union[Type, QueryParam]]] = None,
+    headers: Optional[Mapping[str, Union[str, Header]]] = None,
+    cookies: Optional[Mapping[str, Union[str, Cookie]]] = None,
 ) -> Callable[[Handler], Handler]:
     ...
 
@@ -61,10 +61,10 @@ def request_schema(
     body_required: bool = False,
     body_description: Optional[str] = None,
     body_example: Optional[Any] = None,
-    body_examples: Optional[Dict[str, Union[Example, Any]]] = None,
-    query_params: Optional[Dict[str, Union[Type, QueryParam]]] = None,
-    headers: Optional[Dict[str, Union[str, Header]]] = None,
-    cookies: Optional[Dict[str, Union[str, Cookie]]] = None,
+    body_examples: Optional[Mapping[str, Union[Example, Any]]] = None,
+    query_params: Optional[Mapping[str, Union[Type, QueryParam]]] = None,
+    headers: Optional[Mapping[str, Union[str, Header]]] = None,
+    cookies: Optional[Mapping[str, Union[str, Cookie]]] = None,
 ) -> Callable[[Handler], Handler]:
     def decorator(handler: Handler) -> Handler:
         meta = getattr(handler, __openapify__, [])
@@ -96,9 +96,9 @@ def response_schema(
     http_code: HttpCode = 200,
     media_type: str = "application/json",
     description: Optional[str] = None,
-    headers: Optional[Dict[str, Union[str, Header]]] = None,
+    headers: Optional[Mapping[str, Union[str, Header]]] = None,
     example: Optional[Any] = None,
-    examples: Optional[Dict[str, Union[Example, Any]]] = None,
+    examples: Optional[Mapping[str, Union[Example, Any]]] = None,
 ):
     def decorator(handler):
         meta = getattr(handler, __openapify__, [])
@@ -127,7 +127,7 @@ def path_docs(
     summary: Optional[str] = None,
     description: Optional[str] = None,
     tags: Optional[Sequence[str]] = None,
-    parameters: Optional[Dict[str, Union[str, Parameter]]] = None,
+    parameters: Optional[Mapping[str, Union[str, Parameter]]] = None,
     external_docs: Optional[Union[str, Tuple[str, str]]] = None,
     deprecated: Optional[bool] = None,
 ):
